==> spread-5.6.1.59-py3-none-any.whl: spread-5.6.1.59.data/data/spread/dashboard/static/commissioning/js/commissioning.js <==
queueCount = 0;
let queue = [];

//DatePicker
try {
    $('#date-picker')?.daterangepicker({
            startDate: moment(dateFrom),
            endDate: moment(dateTo),
            opens: 'left',
            maxDate: moment(),
            minDate: moment().subtract(24, 'month'),  //TODO получать самую раннюю дату с данными
            showDropdowns: true,
            linkedCalendars: false,
            locale: {
                format: "DD.MM.YYYY",
                applyLabel: gettext("Применить"),
                cancelLabel: gettext("Отменить"),
            }
        },
        function (start, end, label) {
            let f = 'YYYY-MM-DD';
            if (start.format(f) != dateFrom || end.format(f) != dateTo) {
                resetPage();
            }
        }
    );
    setDatesToLinks(dateFrom, dateTo);
}
catch (e) {}


let printButton = document.getElementById('print-button');
printButton?.addEventListener('click', () => {
    let printWindow = window.open('/spread/commissioning/print?dateFrom=' + dateFrom + '&dateTo=' + dateTo);
});

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(broker['reply'], {});
        $('.state').each((i, node) => {
            client.subscribe(node.id, {});
        });
        setTimeout(getReport, 1000);
    },
    function onMessage(topic, message) {
        if (topic.startsWith('Spread/State')) {
            const targetElement = document.getElementById(topic);
            setValue(targetElement, message.value);

        } else if (message.key.includes('_chart_data')) {
            processChartData(message.key, message.value.data);

        } else if (message.value && message.value.data) {
            setProgress();
            try {
                const consumption = parseFloat(message.value.data.value || 0) / 1000;
                const workTime = parseFloat(message.value.data.workTime || 0);
                for (let suffix of ['', '_sub']) {
                    let targetElement = document.getElementById(message.key + suffix);
                    if (!targetElement) {
                        continue;
                    }
                    if (targetElement?.hasAttribute('partof')) {
                        const hasTargetValue = parseFloat(targetElement.textContent) || 0;
                        for (let sub of ['', '_sub']) {
                            const partof = targetElement.getAttribute('partof') + sub;
                            const amountElement = document.getElementById(partof);
                            if (amountElement) {
                                const amountValue = parseFloat(amountElement.textContent) || 0;
                                amountElement.textContent = (amountValue - hasTargetValue + consumption).toFixed(1);
                            }
                        }
                    }
                    targetElement.textContent = consumption.toFixed(1);
                }
                $('#worktime-' + message.key).text((workTime / 3600000).toFixed(1));

            } catch (e) {
                console.error(e);
            } finally {
                request();
            }
        }
    }
);

function getReport(t1=null, t2=null) {
    try {
        t1 = t1 || dateFrom;
        t2 = t2 || dateTo;

        if (!t1 || !t2){
            return;
        }
        if (queue.length !== 0) {
            alert(gettext('consumption_double_query'));
        }
        else {
            startTime = t1 + 'T00:00:00';
            endTime = t2 + 'T23:59:59';
            console.log('Query chart for period {} .. {}'
                .replace('{}', t1)
                .replace('{}', t2));

            $(document).find('.chartable').each((i, node) => {
                try {
                    queue.push(node);
                } catch (e) {
                    console.error(e);
                }
            });
            queueCount = queue.length; // счетчик уменьшим, когда обработаем ответ
            request();
        }

    } catch (e) {
        console.error(e);
    }
    return false;
}

function request() {
    if (queue.length > 0) {
        const element = queue.shift();
        const topic = element.getAttribute('chart');
        if (topic) {
            client.send(topic, JSON.stringify({
                params: {
                    algorithm: "integral",
                    startTime: startTime,
                    endTime: endTime,
                },
                key: element.id,
                session: broker.guid
            }));
            if (element.hasAttribute('consumption-chart')) {
                let id = element.getAttribute('partof') || element.id;
                if (!(id in chartData)) {
                    let partCount = $('[partof=' + id + ']').length || 1;
                    resetChartData(id, partCount);
                }
                requestChartData(id, topic, startTime, endTime, element.getAttribute('consumption-chart'));
            }
        } else {
            request();
        }
    }
}

function setValue(node, value) {
    if ($(node).hasClass('profiles')) {
        for (var profile in value) {
            if (value.hasOwnProperty(profile)) {
                for (var funit in value[profile]) {
                    if (funit == 'TargetLuminosity') {
                        processLuminosity(node, value, profile, funit);
                    } else {
                        $(node)
                            .find('#' + profile)
                            .find('[name=' + funit + ']')
                            .val(value[profile][funit]);
                    }
                }
            }
        }
    } else if ($(node).is("select,input")) {
        $(node).val(value);
    } else if ($(node).hasClass('percent')) {
        const curveId = node.id.slice(0, node.id.lastIndexOf('/')) + '/DimmingCurve';
        const curveType = document.getElementById(curveId).textContent;
        node.textContent = convertToPercents(value, curveType)
    } else {
        node.textContent = value;
    }
}

function calculateFactor(index) {
    const sensorValue = parseInt($('.sensor_value-' + index).text()) || 1;
    const luxValue = $('#lux_value-' + index).val();
    let factor = $('#id_form-' + index + '-value');
    factor.css({'color': 'red', 'text-align': 'right'});
    factor.val( (sensorValue && (luxValue / sensorValue)).toFixed(3));
}

function convertToPercents(value, curveType=1) {
    if (curveType == 1) {
        return (Math.min(100, Math.round(100 * value / 254)));
    }
    return Math.round(10 ** ((value - 1) * 3 / 253 - 1));
}

let progressElement = document.getElementById("loadProgressBar");
function setProgress() {
    if (progressElement && queueCount != 0) {
        let progress = Math.round((1 - queue.length/queueCount) * 100);
        if (progress >= 95) {
            progress = 0;
            progressElement.hidden = true;
        }
        progressElement.style.width = progress + '%';
    }
}

function resetProgressBar() {
    progressElement.hidden = false;
    progressElement.style.width = '0%';
}

function resetPage() {
    resetProgressBar();
    resetChartData();
    setDatesToLinks();
    getReport();
}

function processLuminosity(node, value, profile, funit) {
    let val = '';
    let lightFactor = parseFloat($(node).attr('factor')?.replace(',', '.'));
    if (!lightFactor) {
        val = gettext('undefined_factor');
    } else {
        let currentValue = value[profile][funit] || 0;
        val = currentValue * lightFactor;
    }
    $(node)
        .find('#' + profile)
        .find('[name=' + funit + ']')
        .val(val);
}

function setDatesToLinks() {
    let format = 'YYYY-MM-DD';
    dateFrom = $('#date-picker').data('daterangepicker').startDate.format(format);
    dateTo = $('#date-picker').data('daterangepicker').endDate.format(format);
    $('.date_link').attr('href', (i, href) => { return href.split('?')[0] + '?dateFrom=' + dateFrom + '&dateTo=' + dateTo });
}

==> spread-5.9.0.59-py3-none-any.whl: spread-5.9.0.59.data/data/spread/dashboard/static/commissioning/js/commissioning.js <==
queueCount = 0;
let queue = [];
let summaryPower = {};

//DatePicker
try {
    $('#date-picker')?.daterangepicker({
            startDate: moment(dateFrom),
            endDate: moment(dateTo),
            opens: 'left',
            maxDate: moment(),
            minDate: moment().subtract(24, 'month'),  //TODO получать самую раннюю дату с данными
            showDropdowns: true,
            linkedCalendars: false,
            locale: {
                format: "DD.MM.YYYY",
                applyLabel: gettext("Применить"),
                cancelLabel: gettext("Отменить"),
            }
        },
        function (start, end, label) {
            let f = 'YYYY-MM-DD';
            if (start.format(f) != dateFrom || end.format(f) != dateTo) {
                resetPage();
            }
        }
    );
    setDatesToLinks(dateFrom, dateTo);
}
catch (e) {}


let printButton = document.getElementById('print-button');
let printLocationButton = document.getElementById('print-location-button');

printButton?.addEventListener('click', () => {openPrintTab()});
printLocationButton?.addEventListener('click', () => {openPrintTab(parseLocationId())});

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(broker['reply'], {});
        $('.state').each((i, node) => {
            let topic = node.getAttribute('topic')
            client.subscribe(topic, {});
        });
        setTimeout(getReport, 1000);
    },
    function onMessage(topic, message) {
        if (topic.startsWith('Spread/State')) {
            // const targetElement = document.getElementById(topic);
            $('[topic="'+topic+'"]').each((i, node) => {
                setValue(node, message.value);
            });

        } else if (message.key?.includes('_chart_data')) {
            processChartData(message.key, message.value.data);

        } else if (message.value && message.value.data) {
            setProgress();
            try {
                const consumption = parseFloat(message.value.data.value || 0) / 1000;
                const workTime = parseFloat(message.value.data.workTime || 0);
                for (let suffix of ['', '_sub']) {
                    let targetElement = document.getElementById(message.key + suffix);
                    if (!targetElement) {
                        continue;
                    }
                    if (targetElement?.hasAttribute('partof')) {
                        const hasTargetValue = parseFloat(targetElement.textContent) || 0;
                        for (let sub of ['', '_sub']) {
                            const partof = targetElement.getAttribute('partof') + sub;
                            const amountElement = document.getElementById(partof);
                            if (amountElement) {
                                const amountValue = parseFloat(amountElement.textContent) || 0;
                                amountElement.textContent = (amountValue - hasTargetValue + consumption).toFixed(1);
                            }
                        }
                    }
                    targetElement.textContent = consumption.toFixed(1);
                    if ($(targetElement).attr('part-of-summary-power')) {
                        let id = $(targetElement).attr('part-of-summary-power');
                        summaryPower[id] = summaryPower[id] ? summaryPower[id] + consumption : consumption;
                        $('#summary-power-' + id).text(summaryPower[id].toFixed(1));
                    }
                }
                $('#worktime-' + message.key).text((workTime / 3600000).toFixed(1));

            } catch (e) {
                console.error(e);
            } finally {
                request();
            }
        }
    }
);

function getReport(t1=null, t2=null) {
    try {
        t1 = t1 || dateFrom;
        t2 = t2 || dateTo;

        if (!t1 || !t2){
            return;
        }
        if (queue.length !== 0) {
            alert(gettext('consumption_double_query'));
        }
        else {
            startTime = t1 + 'T00:00:00';
            endTime = t2 + 'T23:59:59';
            console.log('Query chart for period {} .. {}'
                .replace('{}', t1)
                .replace('{}', t2));

            $(document).find('.chartable').each((i, node) => {
                try {
                    queue.push(node);
                } catch (e) {
                    console.error(e);
                }
            });
            queueCount = queue.length; // счетчик уменьшим, когда обработаем ответ
            request();
        }

    } catch (e) {
        console.error(e);
    }
    return false;
}

function request() {
    if (queue.length > 0) {
        const element = queue.shift();
        const topic = element.getAttribute('chart');
        if (topic) {
            client.send(topic, JSON.stringify({
                params: {
                    algorithm: "integral",
                    startTime: startTime,
                    endTime: endTime,
                },
                key: element.id,
                session: broker.guid
            }));
            if (element.hasAttribute('consumption-chart')) {
                let id = element.getAttribute('partof') || element.id;
                if (id && !(id in chartData)) {
                    let partCount = $('[partof=' + id + ']').length || 1;
                    resetChartData(id, partCount);
                }
                requestChartData(id, topic, startTime, endTime, element.getAttribute('consumption-chart'));
            }
        } else {
            request();
        }
    }
}

function setValue(node, value) {
    if ($(node).hasClass('profiles')) {
        for (let profile in value) {
            if (value.hasOwnProperty(profile)) {
                processOccupancy(value, profile, node);
                processVacancy(value, profile, node);
                for (var funit in value[profile]) {
                    if (funit == 'TargetLuminosity') {
                        processLuminosity(node, value, profile, funit);
                    } else if (funit == 'HoldTime') {
                        $(node)
                            .find('#' + profile)
                            .find('[name=' + funit + ']')
                            .text(value[profile][funit]);
                    } else {
                        $(node)
                            .find('#' + profile)
                            .find('[name=' + funit + ']')
                            .val(value[profile][funit]);
                    }
                }
            }
        }
    } else if ($(node).is("select,input")) {
        $(node).val(value);
    } else if ($(node).hasClass('percent')) {
        let topic = node.getAttribute('topic');
        const curveId = topic.slice(0, topic.lastIndexOf('/')) + '/DimmingCurve';
        const curveType = document.getElementById(curveId).textContent;
        node.textContent = convertToPercents(value, curveType)
    } else {
        node.textContent = value;
    }
}

function calculateFactor(index) {
    const sensorValue = parseInt($('.sensor_value-' + index).text()) || 1;
    const luxValue = $('#lux_value-' + index).val();
    let factor = $('#id_form-' + index + '-value');
    factor.css({'color': 'red', 'text-align': 'right'});
    factor.val( (sensorValue && (luxValue / sensorValue)).toFixed(3));
}

function convertToPercents(value, curveType=1) {
    if (curveType == 1) {
        return (Math.min(100, Math.round(100 * value / 254)));
    }
    return Math.round(10 ** ((value - 1) * 3 / 253 - 1));
}

let progressElement = document.getElementById("loadProgressBar");
function setProgress() {
    if (progressElement && queueCount != 0) {
        let progress = Math.round((1 - queue.length/queueCount) * 100);
        if (progress >= 95) {
            progress = 0;
            progressElement.hidden = true;
        }
        progressElement.style.width = progress + '%';
    }
}

function resetProgressBar() {
    progressElement.hidden = false;
    progressElement.style.width = '0%';
}

function resetPage() {
    resetProgressBar();
    resetChartData();
    hideCharts();
    setDatesToLinks();
    getReport();
}

function processLuminosity(node, value, profile, funit) {
    let val = '';
    let lightFactor = parseFloat($(node).attr('factor')?.replace(',', '.'));
    if (!lightFactor) {
        val = gettext('undefined_factor');
    } else {
        let currentValue = value[profile][funit] || 0;
        val = currentValue * lightFactor;
    }
    if (typeof val == 'number') {
        val = Math.round(val);
    }
    $(node)
        .find('#' + profile)
        .find('[name=' + funit + ']')
        .text(val);
}

function setDatesToLinks() {
    let format = 'YYYY-MM-DD';
    dateFrom = $('#date-picker').data('daterangepicker').startDate.format(format);
    dateTo = $('#date-picker').data('daterangepicker').endDate.format(format);
    $('.date_link').attr('href', (i, href) => { return href.split('?')[0] + '?dateFrom=' + dateFrom + '&dateTo=' + dateTo });
}

function openPrintTab(location=null) {
    let url = '/spread/commissioning/print?dateFrom=' + dateFrom + '&dateTo=' + dateTo;
    if (location) {
        url += '&location=' + location;
    }
    let printWindow = window.open(url);
}

function parseLocationId() {
    let loc = document.location.pathname;
    loc = loc.split('/');
    return loc[3];
}

function processOccupancy(value, profile, node) {
    let occupancyValue = null;
    switch (value[profile].OccupancyAction) {
        case 'Level':
            occupancyValue = value[profile].OccupancyLevel;
            break;
        case 'Scene':
            occupancyValue = value[profile].OccupancyScene;
            break;
    }
    $(node)
        .find('#' + profile)
        .find('[name=OccupancyValue]')
        .text(occupancyValue);
}

function processVacancy(value, profile, node) {
    let vacancyValue = null;
    switch (value[profile].VacancyAction) {
        case 'Level':
            vacancyValue = value[profile].VacancyLevel;
            break;
        case 'Scene':
            vacancyValue = value[profile].VacancyScene;
            break;
    }
    $(node)
        .find('#' + profile)
        .find('[name=VacancyValue]')
        .text(vacancyValue);
}
